@@ -4,7 +4,7 @@ import numpy as np
 import pandas as pd
 print("login...")
 
-api=IQOption("tribolinux@gmail.com","tribopass@123","DEMO")
+api=IQOption("emerson@ejtrader.com","Olatikas@123","DEMO")
 
 symbol="EURUSD"
 timeframe="M1"
